%% Raw data reduction of theta/alpha tACS Simon task study
%- Authors: J. van Driel, I.G. Sligte, J. Linders, D. Elport & M.X Cohen
%- correspondence: joramvandriel@gmail.com


clear, close all

%% load data from output txt files

readdir = '/path/to/rawdata/theta_session/';
cd(readdir);

filz_pre  = dir('*_PRE-STIM_EEG.txt');
filz_stim = dir('*_STIM.txt');
filz_post = dir('*_POST-STIM.txt');

savedir = '/path/to/directory/for/saving/';

%-% Get RT for each subject

theta_pre = cell(1,length(filz_pre));
theta_stim = cell(1,length(filz_stim));
theta_post = cell(1,length(filz_post));

congruency_effect_pre_theta = zeros(length(filz_pre),4);
congruency_effect_stim_theta = zeros(length(filz_stim),4);
congruency_effect_post_theta = zeros(length(filz_post),4);

%-%
for s = 1:length(filz_pre)
    
    fid=fopen(filz_pre(s).name,'r'); % this opens the txt file for subject 's'
    theta_date{s} = filz_pre(s).date;
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        theta_pre{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        theta_pre{s}(datarow,2) = str2double(dataline{7}); % RT
        theta_pre{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file
    
    % remove (post-)error correct trials
    errors = find(theta_pre{s}(:,3)==0);
    posterrors = errors+1;
    if ~isempty(find(posterrors==501)), posterrors(end)=[]; end
    theta_pre{s}(unique([errors; posterrors]),:)=[];
    
    % some other data reduction
    theta_pre{s}(theta_pre{s}(:,2)==0,:)=[];   % remove no-response trials
    theta_pre{s}(theta_pre{s}(:,2)<100,:)=[];  % remove too fast responses
    
    % some condition coding
    % cC: 31 51
    % cI: 32 52
    % iC: 33 53
    % iI: 34 54
    
    congruency_effect_pre_theta(s,1) = mean( theta_pre{s}(theta_pre{s}(:,1)==31 | theta_pre{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_pre_theta(s,2) = mean( theta_pre{s}(theta_pre{s}(:,1)==33 | theta_pre{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_pre_theta(s,3) = mean( theta_pre{s}(theta_pre{s}(:,1)==32 | theta_pre{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_pre_theta(s,4) = mean( theta_pre{s}(theta_pre{s}(:,1)==34 | theta_pre{s}(:,1)==54, 2) ); % average iI RT
    
    fid=fopen(filz_stim(s).name,'r'); % this opens the txt file for subject 's'
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        theta_stim{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        theta_stim{s}(datarow,2) = str2double(dataline{7}); % RT
        theta_stim{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file
    
    % remove (post-)error correct trials
    errors = find(theta_stim{s}(:,3)==0);
    posterrors = errors+1;
    if ~isempty(find(posterrors==501)), posterrors(end)=[]; end
    theta_stim{s}(unique([errors; posterrors]),:)=[];
    
    % some other data reduction
    theta_stim{s}(theta_stim{s}(:,2)==0,:)=[];   % remove no-response trials
    theta_stim{s}(theta_stim{s}(:,2)<100,:)=[];  % remove too fast responses
    
    congruency_effect_stim_theta(s,1) = mean( theta_stim{s}(theta_stim{s}(:,1)==31 | theta_stim{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_stim_theta(s,2) = mean( theta_stim{s}(theta_stim{s}(:,1)==33 | theta_stim{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_stim_theta(s,3) = mean( theta_stim{s}(theta_stim{s}(:,1)==32 | theta_stim{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_stim_theta(s,4) = mean( theta_stim{s}(theta_stim{s}(:,1)==34 | theta_stim{s}(:,1)==54, 2) ); % average iI RT
    
    
    
    fid=fopen(filz_post(s).name,'r'); % this opens the txt file for subject 's'
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        theta_post{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        theta_post{s}(datarow,2) = str2double(dataline{7}); % RT
        theta_post{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file
    
    % remove (post-)error correct trials
    errors = find(theta_post{s}(:,3)==0);
    posterrors = errors+1;
    if ~isempty(find(posterrors==501)), posterrors(end)=[]; end
    theta_post{s}(unique([errors; posterrors]),:)=[];
    
    % some other data reduction
    theta_post{s}(theta_post{s}(:,2)==0,:)=[];   % remove no-response trials
    theta_post{s}(theta_post{s}(:,2)<100,:)=[];  % remove too fast responses
    
    % some condition coding    
    % cC: 31 51
    % cI: 32 52
    % iC: 33 53
    % iI: 34 54
    
    congruency_effect_post_theta(s,1) = mean( theta_post{s}(theta_post{s}(:,1)==31 | theta_post{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_post_theta(s,2) = mean( theta_post{s}(theta_post{s}(:,1)==33 | theta_post{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_post_theta(s,3) = mean( theta_post{s}(theta_post{s}(:,1)==32 | theta_post{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_post_theta(s,4) = mean( theta_post{s}(theta_post{s}(:,1)==34 | theta_post{s}(:,1)==54, 2) ); % average iI RT


end


%% Load data from output text files

readdir = '/path/to/rawdata/alpha_session/';
cd(readdir);

filz_pre  = dir('*_PRE-STIM_EEG.txt');
filz_stim = dir('*_STIM.txt');
filz_post = dir('*_POST-STIM.txt');

%-% Get RT for each subject

alpha_pre = cell(1,length(filz_pre));
alpha_stim = cell(1,length(filz_stim));
alpha_post = cell(1,length(filz_post));

congruency_effect_pre_alpha = zeros(length(filz_pre),4);
congruency_effect_stim_alpha = zeros(length(filz_stim),4);
congruency_effect_post_alpha = zeros(length(filz_post),4);

for s = 1:length(filz_pre)
    
    fid=fopen(filz_pre(s).name,'r'); % this opens the txt file for subject 's'
    alpha_date{s} = filz_pre(s).date;
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        alpha_pre{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        alpha_pre{s}(datarow,2) = str2double(dataline{7}); % RT
        alpha_pre{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file
    
    % remove (post-)error correct trials
    errors = find(alpha_pre{s}(:,3)==0);
    posterrors = errors+1;
    if ~isempty(find(posterrors==501)), posterrors(end)=[]; end
    alpha_pre{s}(unique([errors; posterrors]),:)=[];
    
    % some other data reduction
    alpha_pre{s}(alpha_pre{s}(:,2)==0,:)=[];   % remove no-response trials
    alpha_pre{s}(alpha_pre{s}(:,2)<100,:)=[];  % remove too fast responses
    
    % some condition coding
    % cC: 31 51
    % cI: 32 52
    % iC: 33 53
    % iI: 34 54
    
    congruency_effect_pre_alpha(s,1) = mean( alpha_pre{s}(alpha_pre{s}(:,1)==31 | alpha_pre{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_pre_alpha(s,2) = mean( alpha_pre{s}(alpha_pre{s}(:,1)==33 | alpha_pre{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_pre_alpha(s,3) = mean( alpha_pre{s}(alpha_pre{s}(:,1)==32 | alpha_pre{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_pre_alpha(s,4) = mean( alpha_pre{s}(alpha_pre{s}(:,1)==34 | alpha_pre{s}(:,1)==54, 2) ); % average iI RT
    
    fid=fopen(filz_stim(s).name,'r'); % this opens the txt file for subject 's'
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        alpha_stim{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        alpha_stim{s}(datarow,2) = str2double(dataline{7}); % RT
        alpha_stim{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file
    
    % remove (post-)error correct trials
    errors = find(alpha_stim{s}(:,3)==0);
    posterrors = errors+1;
    if ~isempty(find(posterrors==501)), posterrors(end)=[]; end
    alpha_stim{s}(unique([errors; posterrors]),:)=[];
    
    % some other data reduction
    alpha_stim{s}(alpha_stim{s}(:,2)==0,:)=[];   % remove no-response trials
    alpha_stim{s}(alpha_stim{s}(:,2)<100,:)=[];  % remove too fast responses
    
    congruency_effect_stim_alpha(s,1) = mean( alpha_stim{s}(alpha_stim{s}(:,1)==31 | alpha_stim{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_stim_alpha(s,2) = mean( alpha_stim{s}(alpha_stim{s}(:,1)==33 | alpha_stim{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_stim_alpha(s,3) = mean( alpha_stim{s}(alpha_stim{s}(:,1)==32 | alpha_stim{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_stim_alpha(s,4) = mean( alpha_stim{s}(alpha_stim{s}(:,1)==34 | alpha_stim{s}(:,1)==54, 2) ); % average iI RT
    
    
    
    fid=fopen(filz_post(s).name,'r'); % this opens the txt file for subject 's'
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        alpha_post{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        alpha_post{s}(datarow,2) = str2double(dataline{7}); % RT
        alpha_post{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file
    
    % remove (post-)error correct trials
    errors = find(alpha_post{s}(:,3)==0);
    posterrors = errors+1;
    if ~isempty(find(posterrors==501)), posterrors(end)=[]; end
    alpha_post{s}(unique([errors; posterrors]),:)=[];
    
    % some other data reduction
    alpha_post{s}(alpha_post{s}(:,2)==0,:)=[];   % remove no-response trials
    alpha_post{s}(alpha_post{s}(:,2)<100,:)=[];  % remove too fast responses
    
    % some condition coding
    % cC: 31 51
    % cI: 32 52
    % iC: 33 53
    % iI: 34 54
    
    congruency_effect_post_alpha(s,1) = mean( alpha_post{s}(alpha_post{s}(:,1)==31 | alpha_post{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_post_alpha(s,2) = mean( alpha_post{s}(alpha_post{s}(:,1)==33 | alpha_post{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_post_alpha(s,3) = mean( alpha_post{s}(alpha_post{s}(:,1)==32 | alpha_post{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_post_alpha(s,4) = mean( alpha_post{s}(alpha_post{s}(:,1)==34 | alpha_post{s}(:,1)==54, 2) ); % average iI RT
    
    
end

%% EXPORT TO SPSS

newfile = [writdir 'spss_RT_data.txt'];
fid = fopen(newfile, 'w');

spss_data(:,1:4)  = congruency_effect_pre_theta;
spss_data(:,5:8)  = congruency_effect_stim_theta;
spss_data(:,9:12) = congruency_effect_post_theta;

spss_data(:,13:16) = congruency_effect_pre_alpha;
spss_data(:,17:20) = congruency_effect_stim_alpha;
spss_data(:,21:24) = congruency_effect_post_alpha;

spss_colnames = {'theta_pre_cC','theta_pre_iC','theta_pre_cI','theta_pre_iI',...
                 'theta_stim_cC','theta_stim_iC','theta_stim_cI','theta_stim_iI',...
                 'theta_post_cC','theta_post_iC','theta_post_cI','theta_post_iI',...
                 'alpha_pre_cC','alpha_pre_iC','alpha_pre_cI','alpha_pre_iI',...
                 'alpha_stim_cC','alpha_stim_iC','alpha_stim_cI','alpha_stim_iI',...
                 'alpha_post_cC','alpha_post_iC','alpha_post_cI','alpha_post_iI'};

for col=1:length(spss_colnames)
    fprintf(fid,'%s\t',spss_colnames{col});
end
fprintf(fid,'\n');

for row=1:length(filz_pre);
    for col=1:length(spss_colnames)
        fprintf(fid,'%s\t',spss_data(row,col));
    end
    fprintf(fid,'\n');
end

fclose(fid);

%% SAVE RELEVANT VARIABLES

RT.congruency_effect_pre_theta = congruency_effect_pre_theta;
RT.congruency_effect_stim_theta = congruency_effect_stim_theta;
RT.congruency_effect_post_theta = congruency_effect_post_theta;

RT.congruency_effect_pre_alpha = congruency_effect_pre_alpha;
RT.congruency_effect_stim_alpha = congruency_effect_stim_alpha;
RT.congruency_effect_post_alpha = congruency_effect_post_alpha;

cd(savedir)
load all_relevant_behav % -- if script4behavior_acc.m is run first
tACSdat.RT = RT;
save all_relevant_behav tACSdat


%% REMOVE LINEAR TREND; KEEP RESIDUALS

theta_pre_RES = theta_pre;
theta_stim_RES = theta_stim;
theta_post_RES = theta_post;
alpha_pre_RES = alpha_pre;
alpha_stim_RES = alpha_stim;
alpha_post_RES = alpha_post;

%%
for s=1:length(filz_pre)
    
    %% fit least square model of average RT decrease and remove estimated mean to get residual
    
    if datenum(theta_date{s}(1:11))<datenum(alpha_date{s}(1:11)), session=[1 2]; else session=[2 1]; end 
    
    % this is the complete regression model, taking into account: session,
    % block and trial order; in the paper, a more simple model of only
    % block order was used; the results are similar for the two models
    
    X = [ones(length(theta_pre{s}),1) session(1)*ones(length(theta_pre{s}),1)  1*ones(length(theta_pre{s}),1)  (1:length(theta_pre{s}))';
        ones(length(theta_stim{s}),1) session(1)*ones(length(theta_stim{s}),1) 2*ones(length(theta_stim{s}),1) (1:length(theta_stim{s}))';
        ones(length(theta_post{s}),1) session(1)*ones(length(theta_post{s}),1) 3*ones(length(theta_post{s}),1) (1:length(theta_post{s}))';
        ones(length(alpha_pre{s}),1)  session(2)*ones(length(alpha_pre{s}),1)  1*ones(length(alpha_pre{s}),1)  (1:length(alpha_pre{s}))';
        ones(length(alpha_stim{s}),1) session(2)*ones(length(alpha_stim{s}),1) 2*ones(length(alpha_stim{s}),1) (1:length(alpha_stim{s}))' ;
        ones(length(alpha_post{s}),1) session(2)*ones(length(alpha_post{s}),1) 3*ones(length(alpha_post{s}),1) (1:length(alpha_post{s}))'];
    
    Y = [theta_pre{s}(:,2); theta_stim{s}(:,2); theta_post{s}(:,2);
         alpha_pre{s}(:,2); alpha_stim{s}(:,2); alpha_post{s}(:,2);];
     
    % least square fit 
    linreg = (X'*X)\X'*Y;
    
    % compute the regression model and remove from real data
    theta_pre_RES{s}(:,2)  = theta_pre{s}(:,2) - (repmat(linreg(1)+linreg(2)*session(1)+linreg(3)*1, [length(theta_pre{s})  1])+linreg(4)*(1:length(theta_pre{s}))');
    theta_stim_RES{s}(:,2) = theta_stim{s}(:,2)- (repmat(linreg(1)+linreg(2)*session(1)+linreg(3)*2, [length(theta_stim{s}) 1])+linreg(4)*(1:length(theta_stim{s}))');
    theta_post_RES{s}(:,2) = theta_post{s}(:,2)- (repmat(linreg(1)+linreg(2)*session(1)+linreg(3)*3, [length(theta_post{s}) 1])+linreg(4)*(1:length(theta_post{s}))');

    alpha_pre_RES{s}(:,2)  = alpha_pre{s}(:,2) - (repmat(linreg(1)+linreg(2)*session(2)+linreg(3)*1, [length(alpha_pre{s})  1])+linreg(4)*(1:length(alpha_pre{s}))');
    alpha_stim_RES{s}(:,2) = alpha_stim{s}(:,2)- (repmat(linreg(1)+linreg(2)*session(2)+linreg(3)*2, [length(alpha_stim{s}) 1])+linreg(4)*(1:length(alpha_stim{s}))');
    alpha_post_RES{s}(:,2) = alpha_post{s}(:,2)- (repmat(linreg(1)+linreg(2)*session(2)+linreg(3)*3, [length(alpha_post{s}) 1])+linreg(4)*(1:length(alpha_post{s}))');
    
    %%

    % cC: 31 51
    % cI: 32 52
    % iC: 33 53
    % iI: 34 54
    
    congruency_effect_pre_theta(s,1) = mean( theta_pre_RES{s}(theta_pre_RES{s}(:,1)==31 | theta_pre_RES{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_pre_theta(s,2) = mean( theta_pre_RES{s}(theta_pre_RES{s}(:,1)==33 | theta_pre_RES{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_pre_theta(s,3) = mean( theta_pre_RES{s}(theta_pre_RES{s}(:,1)==32 | theta_pre_RES{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_pre_theta(s,4) = mean( theta_pre_RES{s}(theta_pre_RES{s}(:,1)==34 | theta_pre_RES{s}(:,1)==54, 2) ); % average iI RT
    
    congruency_effect_post_theta(s,1) = mean( theta_post_RES{s}(theta_post_RES{s}(:,1)==31 | theta_post_RES{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_post_theta(s,2) = mean( theta_post_RES{s}(theta_post_RES{s}(:,1)==33 | theta_post_RES{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_post_theta(s,3) = mean( theta_post_RES{s}(theta_post_RES{s}(:,1)==32 | theta_post_RES{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_post_theta(s,4) = mean( theta_post_RES{s}(theta_post_RES{s}(:,1)==34 | theta_post_RES{s}(:,1)==54, 2) ); % average iI RT

    congruency_effect_stim_theta(s,1) = mean( theta_stim_RES{s}(theta_stim_RES{s}(:,1)==31 | theta_stim_RES{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_stim_theta(s,2) = mean( theta_stim_RES{s}(theta_stim_RES{s}(:,1)==33 | theta_stim_RES{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_stim_theta(s,3) = mean( theta_stim_RES{s}(theta_stim_RES{s}(:,1)==32 | theta_stim_RES{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_stim_theta(s,4) = mean( theta_stim_RES{s}(theta_stim_RES{s}(:,1)==34 | theta_stim_RES{s}(:,1)==54, 2) ); % average iI RT
        
    congruency_effect_pre_alpha(s,1) = mean( alpha_pre_RES{s}(alpha_pre_RES{s}(:,1)==31 | alpha_pre_RES{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_pre_alpha(s,2) = mean( alpha_pre_RES{s}(alpha_pre_RES{s}(:,1)==33 | alpha_pre_RES{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_pre_alpha(s,3) = mean( alpha_pre_RES{s}(alpha_pre_RES{s}(:,1)==32 | alpha_pre_RES{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_pre_alpha(s,4) = mean( alpha_pre_RES{s}(alpha_pre_RES{s}(:,1)==34 | alpha_pre_RES{s}(:,1)==54, 2) ); % average iI RT
    
    congruency_effect_post_alpha(s,1) = mean( alpha_post_RES{s}(alpha_post_RES{s}(:,1)==31 | alpha_post_RES{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_post_alpha(s,2) = mean( alpha_post_RES{s}(alpha_post_RES{s}(:,1)==33 | alpha_post_RES{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_post_alpha(s,3) = mean( alpha_post_RES{s}(alpha_post_RES{s}(:,1)==32 | alpha_post_RES{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_post_alpha(s,4) = mean( alpha_post_RES{s}(alpha_post_RES{s}(:,1)==34 | alpha_post_RES{s}(:,1)==54, 2) ); % average iI RT

    congruency_effect_stim_alpha(s,1) = mean( alpha_stim_RES{s}(alpha_stim_RES{s}(:,1)==31 | alpha_stim_RES{s}(:,1)==51, 2) ); % average cC RT
    congruency_effect_stim_alpha(s,2) = mean( alpha_stim_RES{s}(alpha_stim_RES{s}(:,1)==33 | alpha_stim_RES{s}(:,1)==53, 2) ); % average iC RT
    congruency_effect_stim_alpha(s,3) = mean( alpha_stim_RES{s}(alpha_stim_RES{s}(:,1)==32 | alpha_stim_RES{s}(:,1)==52, 2) ); % average cI RT
    congruency_effect_stim_alpha(s,4) = mean( alpha_stim_RES{s}(alpha_stim_RES{s}(:,1)==34 | alpha_stim_RES{s}(:,1)==54, 2) ); % average iI RT
    
end


%% EXPORT TO SPSS

% cd ../../Results
newfile = [savedir 'spss_RTres_data.txt'];
fid = fopen(newfile, 'w');

spss_data(:,1:4)  = congruency_effect_pre_theta;
spss_data(:,5:8)  = congruency_effect_stim_theta;
spss_data(:,9:12) = congruency_effect_post_theta;

spss_data(:,13:16) = congruency_effect_pre_alpha;
spss_data(:,17:20) = congruency_effect_stim_alpha;
spss_data(:,21:24) = congruency_effect_post_alpha;

spss_colnames = {'theta_pre_cC','theta_pre_iC','theta_pre_cI','theta_pre_iI',...
                 'theta_stim_cC','theta_stim_iC','theta_stim_cI','theta_stim_iI',...
                 'theta_post_cC','theta_post_iC','theta_post_cI','theta_post_iI',...
                 'alpha_pre_cC','alpha_pre_iC','alpha_pre_cI','alpha_pre_iI',...
                 'alpha_stim_cC','alpha_stim_iC','alpha_stim_cI','alpha_stim_iI',...
                 'alpha_post_cC','alpha_post_iC','alpha_post_cI','alpha_post_iI'};

for col=1:length(spss_colnames)
    fprintf(fid,'%s\t',spss_colnames{col});
end
fprintf(fid,'\n');

for row=1:length(filz_pre);
    for col=1:length(spss_colnames)
        fprintf(fid,'%s\t',spss_data(row,col));
    end
    fprintf(fid,'\n');
end

fclose(fid);

%% SAVE RELEVANT VARIABLES

RTres.congruency_effect_pre_theta = congruency_effect_pre_theta;
RTres.congruency_effect_stim_theta = congruency_effect_stim_theta;
RTres.congruency_effect_post_theta = congruency_effect_post_theta;

RTres.congruency_effect_pre_alpha = congruency_effect_pre_alpha;
RTres.congruency_effect_stim_alpha = congruency_effect_stim_alpha;
RTres.congruency_effect_post_alpha = congruency_effect_post_alpha;

cd(savedir)
load all_relevant_behav
tACSdat.RTres = RTres;
save all_relevant_behav tACSdat

