%% Raw data reduction of theta/alpha tACS Simon task study
%- Authors: J. van Driel, I.G. Sligte, J. Linders, D. Elport & M.X Cohen
%- correspondence: joramvandriel@gmail.com


clear, close all

%% load data from output txt files

readdir = '/path/to/rawdata/theta_session/';
cd(readdir);

filz_pre  = dir('*_PRE-STIM_EEG.txt');
filz_stim = dir('*_STIM.txt');
filz_post = dir('*_POST-STIM.txt');

savedir = '/path/to/directory/for/saving/';

%-% Get accuracy for each subject

theta_pre = cell(1,length(filz_pre));
theta_stim = cell(1,length(filz_stim));
theta_post = cell(1,length(filz_post));

congruency_effect_pre_theta = zeros(length(filz_pre),4);
congruency_effect_stim_theta = zeros(length(filz_stim),4);
congruency_effect_post_theta = zeros(length(filz_post),4);

%-%
for s = 1:length(filz_pre)
    
    fid=fopen(filz_pre(s).name,'r'); % this opens the txt file for subject 's'
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        theta_pre{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        theta_pre{s}(datarow,2) = str2double(dataline{7}); % RT
        theta_pre{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file
        
    % some other data reduction
    theta_pre{s}(theta_pre{s}(:,2)==0,:)=[];   % remove no-response trials
    theta_pre{s}(theta_pre{s}(:,2)<100,:)=[];  % remove too fast responses
    
    
    % cC: 31 51
    % cI: 32 52
    % iC: 33 53
    % iI: 34 54
    
    congruency_effect_pre_theta(s,1) = mean( theta_pre{s}(theta_pre{s}(:,1)==31 | theta_pre{s}(:,1)==51, 3) ); % average cC accuracy
    congruency_effect_pre_theta(s,2) = mean( theta_pre{s}(theta_pre{s}(:,1)==33 | theta_pre{s}(:,1)==53, 3) ); % average iC accuracy
    congruency_effect_pre_theta(s,3) = mean( theta_pre{s}(theta_pre{s}(:,1)==32 | theta_pre{s}(:,1)==52, 3) ); % average cI accuracy
    congruency_effect_pre_theta(s,4) = mean( theta_pre{s}(theta_pre{s}(:,1)==34 | theta_pre{s}(:,1)==54, 3) ); % average iI accuracy
    
    fid=fopen(filz_stim(s).name,'r'); % this opens the txt file for subject 's'
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        theta_stim{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        theta_stim{s}(datarow,2) = str2double(dataline{7}); % RT
        theta_stim{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file
        
    % some other data reduction
    theta_stim{s}(theta_stim{s}(:,2)==0,:)=[];   % remove no-response trials
    theta_stim{s}(theta_stim{s}(:,2)<100,:)=[];  % remove too fast responses
    
    congruency_effect_stim_theta(s,1) = mean( theta_stim{s}(theta_stim{s}(:,1)==31 | theta_stim{s}(:,1)==51, 3) ); % average cC accuracy
    congruency_effect_stim_theta(s,2) = mean( theta_stim{s}(theta_stim{s}(:,1)==33 | theta_stim{s}(:,1)==53, 3) ); % average iC accuracy
    congruency_effect_stim_theta(s,3) = mean( theta_stim{s}(theta_stim{s}(:,1)==32 | theta_stim{s}(:,1)==52, 3) ); % average cI accuracy
    congruency_effect_stim_theta(s,4) = mean( theta_stim{s}(theta_stim{s}(:,1)==34 | theta_stim{s}(:,1)==54, 3) ); % average iI accuracy
    
    
    
    fid=fopen(filz_post(s).name,'r'); % this opens the txt file for subject 's'
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        theta_post{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        theta_post{s}(datarow,2) = str2double(dataline{7}); % RT
        theta_post{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file

    % some other data reduction
    theta_post{s}(theta_post{s}(:,2)==0,:)=[];   % remove no-response trials
    theta_post{s}(theta_post{s}(:,2)<100,:)=[];  % remove too fast responses
    
    
    % cC: 31 51
    % cI: 32 52
    % iC: 33 53
    % iI: 34 54
    
    congruency_effect_post_theta(s,1) = mean( theta_post{s}(theta_post{s}(:,1)==31 | theta_post{s}(:,1)==51, 3) ); % average cC accuracy
    congruency_effect_post_theta(s,2) = mean( theta_post{s}(theta_post{s}(:,1)==33 | theta_post{s}(:,1)==53, 3) ); % average iC accuracy
    congruency_effect_post_theta(s,3) = mean( theta_post{s}(theta_post{s}(:,1)==32 | theta_post{s}(:,1)==52, 3) ); % average cI accuracy
    congruency_effect_post_theta(s,4) = mean( theta_post{s}(theta_post{s}(:,1)==34 | theta_post{s}(:,1)==54, 3) ); % average iI accuracy

    
end


%% Load data from output text files

readdir = '/path/to/rawdata/alpha_session/';
cd(readdir);

filz_pre  = dir('*_PRE-STIM_EEG.txt');
filz_stim = dir('*_STIM.txt');
filz_post = dir('*_POST-STIM.txt');

%-% Get accuracy for each subject

alpha_pre = cell(1,length(filz_pre));
alpha_stim = cell(1,length(filz_stim));
alpha_post = cell(1,length(filz_post));

congruency_effect_pre_alpha = zeros(length(filz_pre),4);
congruency_effect_stim_alpha = zeros(length(filz_stim),4);
congruency_effect_post_alpha = zeros(length(filz_post),4);

for s = 1:length(filz_pre)
    
    fid=fopen(filz_pre(s).name,'r'); % this opens the txt file for subject 's'
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        alpha_pre{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        alpha_pre{s}(datarow,2) = str2double(dataline{7}); % RT
        alpha_pre{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file
    
    % some other data reduction
    alpha_pre{s}(alpha_pre{s}(:,2)==0,:)=[];   % remove no-response trials
    alpha_pre{s}(alpha_pre{s}(:,2)<100,:)=[];  % remove too fast responses
    
    
    % cC: 31 51
    % cI: 32 52
    % iC: 33 53
    % iI: 34 54
    
    congruency_effect_pre_alpha(s,1) = mean( alpha_pre{s}(alpha_pre{s}(:,1)==31 | alpha_pre{s}(:,1)==51, 3) ); % average cC accuracy
    congruency_effect_pre_alpha(s,2) = mean( alpha_pre{s}(alpha_pre{s}(:,1)==33 | alpha_pre{s}(:,1)==53, 3) ); % average iC accuracy
    congruency_effect_pre_alpha(s,3) = mean( alpha_pre{s}(alpha_pre{s}(:,1)==32 | alpha_pre{s}(:,1)==52, 3) ); % average cI accuracy
    congruency_effect_pre_alpha(s,4) = mean( alpha_pre{s}(alpha_pre{s}(:,1)==34 | alpha_pre{s}(:,1)==54, 3) ); % average iI accuracy
    
    fid=fopen(filz_stim(s).name,'r'); % this opens the txt file for subject 's'
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        alpha_stim{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        alpha_stim{s}(datarow,2) = str2double(dataline{7}); % RT
        alpha_stim{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file
    
    % some other data reduction
    alpha_stim{s}(alpha_stim{s}(:,2)==0,:)=[];   % remove no-response trials
    alpha_stim{s}(alpha_stim{s}(:,2)<100,:)=[];  % remove too fast responses
    
    congruency_effect_stim_alpha(s,1) = mean( alpha_stim{s}(alpha_stim{s}(:,1)==31 | alpha_stim{s}(:,1)==51, 3) ); % average cC accuracy
    congruency_effect_stim_alpha(s,2) = mean( alpha_stim{s}(alpha_stim{s}(:,1)==33 | alpha_stim{s}(:,1)==53, 3) ); % average iC accuracy
    congruency_effect_stim_alpha(s,3) = mean( alpha_stim{s}(alpha_stim{s}(:,1)==32 | alpha_stim{s}(:,1)==52, 3) ); % average cI accuracy
    congruency_effect_stim_alpha(s,4) = mean( alpha_stim{s}(alpha_stim{s}(:,1)==34 | alpha_stim{s}(:,1)==54, 3) ); % average iI accuracy
    
    
    
    fid=fopen(filz_post(s).name,'r'); % this opens the txt file for subject 's'
    
    datarow=1; % this variable is to increment the below loop line per line
    
    while ~feof(fid)
        
        dataline=fgetl(fid); % this reads in the next line in the txt file
        dataline=regexp(dataline,'\t','split'); % splits it up again
        
        alpha_post{s}(datarow,1) = str2double(dataline{6}); % prevCURR stimcode
        alpha_post{s}(datarow,2) = str2double(dataline{7}); % RT
        alpha_post{s}(datarow,3) = str2double(dataline{9}); % accuracy
        
        datarow=datarow+1; % increment with one to go to the next line
        
    end
    
    fclose(fid); % close the file
        
    % some other data reduction
    alpha_post{s}(alpha_post{s}(:,2)==0,:)=[];   % remove no-response trials
    alpha_post{s}(alpha_post{s}(:,2)<100,:)=[];  % remove too fast responses
    
    
    % cC: 31 51
    % cI: 32 52
    % iC: 33 53
    % iI: 34 54
    
    congruency_effect_post_alpha(s,1) = mean( alpha_post{s}(alpha_post{s}(:,1)==31 | alpha_post{s}(:,1)==51, 3) ); % average cC accuracy
    congruency_effect_post_alpha(s,2) = mean( alpha_post{s}(alpha_post{s}(:,1)==33 | alpha_post{s}(:,1)==53, 3) ); % average iC accuracy
    congruency_effect_post_alpha(s,3) = mean( alpha_post{s}(alpha_post{s}(:,1)==32 | alpha_post{s}(:,1)==52, 3) ); % average cI accuracy
    congruency_effect_post_alpha(s,4) = mean( alpha_post{s}(alpha_post{s}(:,1)==34 | alpha_post{s}(:,1)==54, 3) ); % average iI accuracy
        
    
end

%% EXPORT TO SPSS

newfile = [savedir 'spss_acc_data.txt'];
fid = fopen(newfile, 'w');

spss_data(:,1:4)  = congruency_effect_pre_theta;
spss_data(:,5:8)  = congruency_effect_stim_theta;
spss_data(:,9:12) = congruency_effect_post_theta;

spss_data(:,13:16) = congruency_effect_pre_alpha;
spss_data(:,17:20) = congruency_effect_stim_alpha;
spss_data(:,21:24) = congruency_effect_post_alpha;

spss_colnames = {'theta_pre_cC','theta_pre_iC','theta_pre_cI','theta_pre_iI',...
                 'theta_stim_cC','theta_stim_iC','theta_stim_cI','theta_stim_iI',...
                 'theta_post_cC','theta_post_iC','theta_post_cI','theta_post_iI',...
                 'alpha_pre_cC','alpha_pre_iC','alpha_pre_cI','alpha_pre_iI',...
                 'alpha_stim_cC','alpha_stim_iC','alpha_stim_cI','alpha_stim_iI',...
                 'alpha_post_cC','alpha_post_iC','alpha_post_cI','alpha_post_iI'};

for col=1:length(spss_colnames)
    fprintf(fid,'%s\t',spss_colnames{col});
end
fprintf(fid,'\n');

for row=1:length(filz_pre);
    for col=1:length(spss_colnames)
        fprintf(fid,'%s\t',spss_data(row,col));
    end
    fprintf(fid,'\n');
end

fclose(fid);

%% SAVE RELEVANT VARIABLES

accuracy.congruency_effect_pre_theta = congruency_effect_pre_theta;
accuracy.congruency_effect_stim_theta = congruency_effect_stim_theta;
accuracy.congruency_effect_post_theta = congruency_effect_post_theta;

accuracy.congruency_effect_pre_alpha = congruency_effect_pre_alpha;
accuracy.congruency_effect_stim_alpha = congruency_effect_stim_alpha;
accuracy.congruency_effect_post_alpha = congruency_effect_post_alpha;

cd(savedir)
% load all_relevant_behav % -- if script4behavior_RT.m is run first
tACSdat.accuracy = accuracy;
save all_relevant_behav tACSdat


%% REMOVE LINEAR TREND; KEEP RESIDUALS

theta_pre_RES = theta_pre;
theta_stim_RES = theta_stim;
theta_post_RES = theta_post;
alpha_pre_RES = alpha_pre;
alpha_stim_RES = alpha_stim;
alpha_post_RES = alpha_post;

%%
[PES_pre_theta,PES_stim_theta,PES_post_theta,PES_pre_alpha,PES_stim_alpha,PES_post_alpha] = deal(zeros(length(filz_pre),3));

for s=1:length(filz_pre)
    
    %% fit least square model of average RT decrease and remove estimated mean to get residual
    
    if datenum(theta_date{s}(1:11))<datenum(alpha_date{s}(1:11)), session=[1 2]; else session=[2 1]; end 
    
    % this is the simple regression model, with only block order as
    % regressor (as used in the paper); a more complete model also taking
    % into account session (theta/alpha) and trial number is shown in the
    % code for RT; this model did not alter the results
    
    X = [ones(length(theta_pre{s}),1) 1*ones(length(theta_pre{s}),1)  ;
        ones(length(theta_stim{s}),1) 2*ones(length(theta_stim{s}),1) ;
        ones(length(theta_post{s}),1) 3*ones(length(theta_post{s}),1) ;
        ones(length(alpha_pre{s}),1)  1*ones(length(alpha_pre{s}),1)  ;
        ones(length(alpha_stim{s}),1) 2*ones(length(alpha_stim{s}),1)  ;
        ones(length(alpha_post{s}),1) 3*ones(length(alpha_post{s}),1) ];
    
    Y = [theta_pre{s}(:,2); theta_stim{s}(:,2); theta_post{s}(:,2);
         alpha_pre{s}(:,2); alpha_stim{s}(:,2); alpha_post{s}(:,2);];
     
    % least square fit 
    linreg = (X'*X)\X'*Y;
    
    % compute the regression model and remove from real data
    theta_pre_RES{s}(:,2)  = theta_pre{s}(:,2) - (linreg(1)+linreg(2)*1);
    theta_stim_RES{s}(:,2) = theta_stim{s}(:,2)- (linreg(1)+linreg(2)*2);
    theta_post_RES{s}(:,2) = theta_post{s}(:,2)- (linreg(1)+linreg(2)*3);

    alpha_pre_RES{s}(:,2)  = alpha_pre{s}(:,2) - (linreg(1)+linreg(2)*1);
    alpha_stim_RES{s}(:,2) = alpha_stim{s}(:,2)- (linreg(1)+linreg(2)*2);
    alpha_post_RES{s}(:,2) = alpha_post{s}(:,2)- (linreg(1)+linreg(2)*3);
    
    %% Post-error slowing and error-speeding
    
    [cCc,eC,cE] = deal(zeros(length(theta_pre_RES{s}),1));
    
    for i = 2:length(theta_pre_RES{s})-1
        if theta_pre_RES{s}(i-1,3)==1 && theta_pre_RES{s}(i,3)==1 && theta_pre_RES{s}(i+1,3)==1 % tripple correct
            cCc(i) = theta_pre_RES{s}(i,2);
        elseif theta_pre_RES{s}(i-1,3)==0 && theta_pre_RES{s}(i,3)==1 % correct after error (post-error slowing)
            eC(i) = theta_pre_RES{s}(i,2);
        elseif theta_pre_RES{s}(i-1,3)==1 && theta_pre_RES{s}(i,3)==0 % error after correct (error speeding)
            cE(i) = theta_pre_RES{s}(i,2);
        end
    end
    
    cCc(cCc==0)=[];
    eC(eC==0)=[];
    cE(cE==0)=[];
    
    PES_pre_theta(s,:) = [mean(cCc) mean(eC) mean(cE)];
    
    cCc = zeros(length(theta_stim_RES{s}),1);
    eC = zeros(length(theta_stim_RES{s}),1);
    cE = zeros(length(theta_stim_RES{s}),1);
    for i = 2:length(theta_stim_RES{s})-1
        if theta_stim_RES{s}(i-1,3)==1 && theta_stim_RES{s}(i,3)==1 && theta_stim_RES{s}(i+1,3)==1
            cCc(i) = theta_stim_RES{s}(i,2);
        elseif theta_stim_RES{s}(i-1,3)==0 && theta_stim_RES{s}(i,3)==1
            eC(i) = theta_stim_RES{s}(i,2);
        elseif theta_stim_RES{s}(i-1,3)==1 && theta_stim_RES{s}(i,3)==0
            cE(i) = theta_stim_RES{s}(i,2);
        end
    end
    cCc(cCc==0)=[];
    eC(eC==0)=[];
    cE(cE==0)=[];
    
    PES_stim_theta(s,:) = [mean(cCc) mean(eC) mean(cE)];
    
    cCc = zeros(length(theta_post_RES{s}),1);
    eC = zeros(length(theta_post_RES{s}),1);
    cE = zeros(length(theta_post_RES{s}),1);
    for i = 2:length(theta_post_RES{s})-1
        if theta_post_RES{s}(i-1,3)==1 && theta_post_RES{s}(i,3)==1 && theta_post_RES{s}(i+1,3)==1
            cCc(i) = theta_post_RES{s}(i,2);
        elseif theta_post_RES{s}(i-1,3)==0 && theta_post_RES{s}(i,3)==1
            eC(i) = theta_post_RES{s}(i,2);
        elseif theta_post_RES{s}(i-1,3)==1 && theta_post_RES{s}(i,3)==0
            cE(i) = theta_post_RES{s}(i,2);
        end
    end
    cCc(cCc==0)=[];
    eC(eC==0)=[];
    cE(cE==0)=[];
    
    PES_post_theta(s,:) = [mean(cCc) mean(eC) mean(cE)];
    
    cCc = zeros(length(alpha_pre_RES{s}),1);
    eC = zeros(length(alpha_pre_RES{s}),1);
    cE = zeros(length(alpha_pre_RES{s}),1);
    for i = 2:length(alpha_pre_RES{s})-1
        if alpha_pre_RES{s}(i-1,3)==1 && alpha_pre_RES{s}(i,3)==1 && alpha_pre_RES{s}(i+1,3)==1
            cCc(i) = alpha_pre_RES{s}(i,2);
        elseif alpha_pre_RES{s}(i-1,3)==0 && alpha_pre_RES{s}(i,3)==1
            eC(i) = alpha_pre_RES{s}(i,2);
        elseif alpha_pre_RES{s}(i-1,3)==1 && alpha_pre_RES{s}(i,3)==0
            cE(i) = alpha_pre_RES{s}(i,2);
        end
    end
    cCc(cCc==0)=[];
    eC(eC==0)=[];
    cE(cE==0)=[];
    
    PES_pre_alpha(s,:) = [mean(cCc) mean(eC) mean(cE)];
    
    cCc = zeros(length(alpha_stim_RES{s}),1);
    eC = zeros(length(alpha_stim_RES{s}),1);
    cE = zeros(length(alpha_stim_RES{s}),1);
    for i = 2:length(alpha_stim_RES{s})-1
        if alpha_stim_RES{s}(i-1,3)==1 && alpha_stim_RES{s}(i,3)==1 && alpha_stim_RES{s}(i+1,3)==1
            cCc(i) = alpha_stim_RES{s}(i,2);
        elseif alpha_stim_RES{s}(i-1,3)==0 && alpha_stim_RES{s}(i,3)==1
            eC(i) = alpha_stim_RES{s}(i,2);
        elseif alpha_stim_RES{s}(i-1,3)==1 && alpha_stim_RES{s}(i,3)==0
            cE(i) = alpha_stim_RES{s}(i,2);
        end
    end
    cCc(cCc==0)=[];
    eC(eC==0)=[];
    cE(cE==0)=[];
    
    PES_stim_alpha(s,:) = [mean(cCc) mean(eC) mean(cE)];
    
    cCc = zeros(length(alpha_post_RES{s}),1);
    eC = zeros(length(alpha_post_RES{s}),1);
    cE = zeros(length(alpha_post_RES{s}),1);
    for i = 2:length(alpha_post_RES{s})-1
        if alpha_post_RES{s}(i-1,3)==1 && alpha_post_RES{s}(i,3)==1 && alpha_post_RES{s}(i+1,3)==1
            cCc(i) = alpha_post_RES{s}(i,2);
        elseif alpha_post_RES{s}(i-1,3)==0 && alpha_post_RES{s}(i,3)==1
            eC(i) = alpha_post_RES{s}(i,2);
        elseif alpha_post_RES{s}(i-1,3)==1 && alpha_post_RES{s}(i,3)==0
            cE(i) = alpha_post_RES{s}(i,2);
        end
    end
    cCc(cCc==0)=[];
    eC(eC==0)=[];
    cE(cE==0)=[];
    
    PES_post_alpha(s,:) = [mean(cCc) mean(eC) mean(cE)];
    
end

%% EXPORT TO SPSS

newfile = [savedir 'spss_RTres_PES_data.txt'];
fid = fopen(newfile, 'w');

spss_data = zeros(length(filz_pre),18);
spss_data(:,1:3)  = PES_pre_theta;
spss_data(:,4:6)  = PES_stim_theta;
spss_data(:,7:9)  = PES_post_theta;

spss_data(:,10:12)  = PES_pre_alpha;
spss_data(:,13:15) = PES_stim_alpha;
spss_data(:,16:18)= PES_post_alpha;

spss_colnames = {'theta_pre_cCc','theta_pre_eC','theta_pre_cE','theta_stim_cCc','theta_stim_eC','theta_stim_cE','theta_post_cCc','theta_post_eC','theta_post_cE',...
                 'alpha_pre_cCc','alpha_pre_eC','alpha_pre_cE','alpha_stim_cCc','alpha_stim_eC','alpha_stim_cE','alpha_post_cCc','alpha_post_eC','alpha_post_cE'};

for col=1:length(spss_colnames)
    fprintf(fid,'%s\t',spss_colnames{col});
end
fprintf(fid,'\n');

for row=1:length(filz_pre);
    for col=1:length(spss_colnames)
        fprintf(fid,'%s\t',spss_data(row,col));
    end
    fprintf(fid,'\n');
end

fclose(fid);

%% SAVE RELEVANT VARIABLES

PES.congruency_effect_pre_theta = congruency_effect_pre_theta;
PES.congruency_effect_stim_theta = congruency_effect_stim_theta;
PES.congruency_effect_post_theta = congruency_effect_post_theta;

PES.congruency_effect_pre_alpha = congruency_effect_pre_alpha;
PES.congruency_effect_stim_alpha = congruency_effect_stim_alpha;
PES.congruency_effect_post_alpha = congruency_effect_post_alpha;

cd(savedir)
load all_relevant_behav
tACSdat.PES = PES;
save all_relevant_behav tACSdat
