%% Code to produce figures of paper "Frequency band-specific electrical brain stimulation modulates cognitive control processes"
%- Authors: J. van Driel, I.G. Sligte, J. Linders, D. Elport & M.X Cohen
%- correspondence: joramvandriel@gmail.com


clear, close all

%% LOAD DATA

cd('/path/to/savedir');
load all_relevant_behav

nsubjects = length(tACSdat.RT.congruency_effect_post_alpha);
a = tACSdat.accuracy;
r = tACSdat.RT;

%% peak frequencies as determined through EEG

% EEG data and Matlab scripts that produced these peaks are available upon
% request

thetapeaks = [4.0000    6.2500    4.5000    5.5000    3.2500    4.5000    6.5000    6.7500    6.5000    7.2500    3.2500    4.7500    7.0000    6.5000    6.7500    4.7500 5.7500    3.5000    3.5000    4.0000    6.7500    4.7500    4.5000    5.5000    7.7500    6.2500    5.5000    4.0000    6.2500    7.5000    5.5000];
alphapeaks = [9.0000   12.0100    8.2500   10.5000   11.0100   10.2600   11.2600    9.5000   12.0100   12.2600   12.7600   11.5100   10.5100   12.2600   10.2600   11.7600  8.5000    8.2500   10.5100   11.5100   11.0100   10.2600    9.5000   11.0100   10.0000    9.5000   11.0100    8.2500    9.7500   12.0100   11.2600];
interfreq = alphapeaks - thetapeaks;

%% Compute congruency-sequence effect (CSE)

% CSE is a 2-by-2 matrix: rows contain RT as a function of current
% congruency; columns contain RT as a function of previous congruency
% CSE is here averaged over all pre/stim/post freq conditions

CSE = cell(1,2);
CSE{1} = zeros(2,2);
CSE{2} = zeros(2,2);

CSE{1}(1,1) = mean([r.congruency_effect_pre_theta(:,1); r.congruency_effect_stim_theta(:,1); r.congruency_effect_post_theta(:,1); ...
                    r.congruency_effect_pre_alpha(:,1); r.congruency_effect_stim_alpha(:,1); r.congruency_effect_post_alpha(:,1)]);

CSE{1}(1,2) = mean([r.congruency_effect_pre_theta(:,2); r.congruency_effect_stim_theta(:,2); r.congruency_effect_post_theta(:,2); ...
                    r.congruency_effect_pre_alpha(:,2); r.congruency_effect_stim_alpha(:,2); r.congruency_effect_post_alpha(:,2)]);

CSE{1}(2,1) = mean([r.congruency_effect_pre_theta(:,3); r.congruency_effect_stim_theta(:,3); r.congruency_effect_post_theta(:,3); ...
                    r.congruency_effect_pre_alpha(:,3); r.congruency_effect_stim_alpha(:,3); r.congruency_effect_post_alpha(:,3)]);

CSE{1}(2,2) = mean([r.congruency_effect_pre_theta(:,4); r.congruency_effect_stim_theta(:,4); r.congruency_effect_post_theta(:,4); ...
                    r.congruency_effect_pre_alpha(:,4); r.congruency_effect_stim_alpha(:,4); r.congruency_effect_post_alpha(:,4)]);

                
CSE{2}(1,1) = std([r.congruency_effect_pre_theta(:,1); r.congruency_effect_stim_theta(:,1); r.congruency_effect_post_theta(:,1); ...
                    r.congruency_effect_pre_alpha(:,1); r.congruency_effect_stim_alpha(:,1); r.congruency_effect_post_alpha(:,1)]) /sqrt(nsubjects);

CSE{2}(1,2) = std([r.congruency_effect_pre_theta(:,2); r.congruency_effect_stim_theta(:,2); r.congruency_effect_post_theta(:,2); ...
                    r.congruency_effect_pre_alpha(:,2); r.congruency_effect_stim_alpha(:,2); r.congruency_effect_post_alpha(:,2)]) /sqrt(nsubjects);

CSE{2}(2,1) = std([r.congruency_effect_pre_theta(:,3); r.congruency_effect_stim_theta(:,3); r.congruency_effect_post_theta(:,3); ...
                    r.congruency_effect_pre_alpha(:,3); r.congruency_effect_stim_alpha(:,3); r.congruency_effect_post_alpha(:,3)]) /sqrt(nsubjects);

CSE{2}(2,2) = std([r.congruency_effect_pre_theta(:,4); r.congruency_effect_stim_theta(:,4); r.congruency_effect_post_theta(:,4); ...
                    r.congruency_effect_pre_alpha(:,4); r.congruency_effect_stim_alpha(:,4); r.congruency_effect_post_alpha(:,4)]) /sqrt(nsubjects);

%% == FIG. 2a

figure
subplot(231)
errorbar(CSE{1}(1,:),CSE{2}(1,:),'-sk','markerfacecolor','k'); hold on
errorbar(CSE{1}(2,:),CSE{2}(2,:),':ok','markerfacecolor','w');
set(gca,'xtick',[1 2],'xticklabel',{'c','i'},'xlim',[0.5 2.5],'ylim',[400 500])
legend('C','I','location','southeast')
box off

%% CSE as a function of condition

% Based on Fig. 2a we computed the CSE as one metric: cI-cC (conflict when
% previous was non-conflict) - iI-iC (conflict when previous was also
% conflict)
% Computed for pre/stim/post and theta/alpha

CSE=zeros(3,2,2);

CSE(1,1,1) = mean((r.congruency_effect_pre_theta(:,3)-r.congruency_effect_pre_theta(:,1)) - (r.congruency_effect_pre_theta(:,4)-r.congruency_effect_pre_theta(:,2)));
CSE(2,1,1) = mean((r.congruency_effect_stim_theta(:,3)-r.congruency_effect_stim_theta(:,1)) - (r.congruency_effect_stim_theta(:,4)-r.congruency_effect_stim_theta(:,2)));
CSE(3,1,1) = mean((r.congruency_effect_post_theta(:,3)-r.congruency_effect_post_theta(:,1)) - (r.congruency_effect_post_theta(:,4)-r.congruency_effect_post_theta(:,2)));

CSE(1,2,1) = std((r.congruency_effect_pre_theta(:,3)-r.congruency_effect_pre_theta(:,1)) - (r.congruency_effect_pre_theta(:,4)-r.congruency_effect_pre_theta(:,2))) / sqrt(nsubjects);
CSE(2,2,1) = std((r.congruency_effect_stim_theta(:,3)-r.congruency_effect_stim_theta(:,1)) - (r.congruency_effect_stim_theta(:,4)-r.congruency_effect_stim_theta(:,2))) / sqrt(nsubjects);
CSE(3,2,1) = std((r.congruency_effect_post_theta(:,3)-r.congruency_effect_post_theta(:,1)) - (r.congruency_effect_post_theta(:,4)-r.congruency_effect_post_theta(:,2))) / sqrt(nsubjects);


CSE(1,1,2) = mean((r.congruency_effect_pre_alpha(:,3)-r.congruency_effect_pre_alpha(:,1)) - (r.congruency_effect_pre_alpha(:,4)-r.congruency_effect_pre_alpha(:,2)));
CSE(2,1,2) = mean((r.congruency_effect_stim_alpha(:,3)-r.congruency_effect_stim_alpha(:,1)) - (r.congruency_effect_stim_alpha(:,4)-r.congruency_effect_stim_alpha(:,2)));
CSE(3,1,2) = mean((r.congruency_effect_post_alpha(:,3)-r.congruency_effect_post_alpha(:,1)) - (r.congruency_effect_post_alpha(:,4)-r.congruency_effect_post_alpha(:,2)));

CSE(1,2,2) = std((r.congruency_effect_pre_alpha(:,3)-r.congruency_effect_pre_alpha(:,1)) - (r.congruency_effect_pre_alpha(:,4)-r.congruency_effect_pre_alpha(:,2))) / sqrt(nsubjects);
CSE(2,2,2) = std((r.congruency_effect_stim_alpha(:,3)-r.congruency_effect_stim_alpha(:,1)) - (r.congruency_effect_stim_alpha(:,4)-r.congruency_effect_stim_alpha(:,2))) / sqrt(nsubjects);
CSE(3,2,2) = std((r.congruency_effect_post_alpha(:,3)-r.congruency_effect_post_alpha(:,1)) - (r.congruency_effect_post_alpha(:,4)-r.congruency_effect_post_alpha(:,2))) / sqrt(nsubjects);

%% == FIG. 2b

subplot(232)
plot([1:3],CSE(:,1,1),'-r^'); hold on
plot([1:3],CSE(:,1,2),'-b^');
set(gca,'xlim',[0 4],'ylim',[30 70])
box off
set(gca,'xtick',[],'xcolor','w')
h=text(1,48,'pre'); set(h,'HorizontalAlignment','center');
h=text(2,38,'stim'); set(h,'HorizontalAlignment','center');
h=text(3,42,'post'); set(h,'HorizontalAlignment','center');
h=text(2,68,'theta'); set(h,'color','r');
h=text(2,63,'alpha'); set(h,'color','b');

%% Stimulation effect as a function of congruency

% The next figure is kind of the other way around: given the overall
% stimulation effect (reduced CSE during stim), we computed for all
% congruency types (cC, cI, iC, iI) the stimulation effect by
% [stim-pre]-[post-pre], and replotted the CSE as in Fig.2a
% Here, we use the residual RT after removing the linear trend of reduced
% RT over blocks as a result of practice

r = tACSdat.RTres;

CSE = cell(1,2);

CSE{1} = zeros(nsubjects,2,2);
CSE{2} = zeros(nsubjects,2,2);

CSE{1}(:,1,1) = (r.congruency_effect_stim_theta(:,1) - r.congruency_effect_pre_theta(:,1)) - (r.congruency_effect_post_theta(:,1) - r.congruency_effect_pre_theta(:,1)); % cC
CSE{1}(:,1,2) = (r.congruency_effect_stim_theta(:,2) - r.congruency_effect_pre_theta(:,2)) - (r.congruency_effect_post_theta(:,2) - r.congruency_effect_pre_theta(:,2)); % iC
CSE{1}(:,2,1) = (r.congruency_effect_stim_theta(:,3) - r.congruency_effect_pre_theta(:,3)) - (r.congruency_effect_post_theta(:,3) - r.congruency_effect_pre_theta(:,3)); % cI
CSE{1}(:,2,2) = (r.congruency_effect_stim_theta(:,4) - r.congruency_effect_pre_theta(:,4)) - (r.congruency_effect_post_theta(:,4) - r.congruency_effect_pre_theta(:,4)); % iI

CSE{2}(:,1,1) = (r.congruency_effect_stim_alpha(:,1) - r.congruency_effect_pre_alpha(:,1)) - (r.congruency_effect_post_alpha(:,1) - r.congruency_effect_pre_alpha(:,1)); % cC
CSE{2}(:,1,2) = (r.congruency_effect_stim_alpha(:,2) - r.congruency_effect_pre_alpha(:,2)) - (r.congruency_effect_post_alpha(:,2) - r.congruency_effect_pre_alpha(:,2)); % iC
CSE{2}(:,2,1) = (r.congruency_effect_stim_alpha(:,3) - r.congruency_effect_pre_alpha(:,3)) - (r.congruency_effect_post_alpha(:,3) - r.congruency_effect_pre_alpha(:,3)); % cI
CSE{2}(:,2,2) = (r.congruency_effect_stim_alpha(:,4) - r.congruency_effect_pre_alpha(:,4)) - (r.congruency_effect_post_alpha(:,4) - r.congruency_effect_pre_alpha(:,4)); % iI

%% == FIG. 2d

subplot(234)
errorbar([1 2],squeeze(mean(CSE{1}(:,1,:))),squeeze(std(CSE{1}(:,1,:)))./sqrt(nsubjects),'-sr','markerfacecolor','r'); hold on
errorbar([1 2],squeeze(mean(CSE{1}(:,2,:))),squeeze(std(CSE{1}(:,2,:)))./sqrt(nsubjects),':or','markerfacecolor','r');
errorbar([3 4],squeeze(mean(CSE{2}(:,1,:))),squeeze(std(CSE{2}(:,1,:)))./sqrt(nsubjects),'-sb','markerfacecolor','b'); hold on
errorbar([3 4],squeeze(mean(CSE{2}(:,2,:))),squeeze(std(CSE{2}(:,2,:)))./sqrt(nsubjects),':ob','markerfacecolor','b');
set(gca,'xtick',[1 2 3 4],'xticklabel',{'c','i','c','i'},'xlim',[0.5 4.5],'ylim',[-10 20],'tickdir','out')
box off
ylabel('residual RT (ms)')
xlabel('prev congruency')
title('[stim-pre]-[post-pre]')
h=text(2.75,17,'theta'); set(h,'color','r');
h=text(2.75,14,'alpha'); set(h,'color','b');

%% Stimulation after-effect as a function of congruency

% Statistical analyses indicated a linear decrease of conflict adaptation
% (iI-iC), on residual RT, suggesting a stimulation after-effect; this
% effect was defined as post-pre, and plotted as a function of previous and
% current trial congruency

CSE{1}(:,1,1) = (r.congruency_effect_post_theta(:,1) - r.congruency_effect_pre_theta(:,1)); % cC
CSE{1}(:,1,2) = (r.congruency_effect_post_theta(:,2) - r.congruency_effect_pre_theta(:,2)); % iC
CSE{1}(:,2,1) = (r.congruency_effect_post_theta(:,3) - r.congruency_effect_pre_theta(:,3)); % cI
CSE{1}(:,2,2) = (r.congruency_effect_post_theta(:,4) - r.congruency_effect_pre_theta(:,4)); % iI

CSE{2}(:,1,1) = (r.congruency_effect_post_alpha(:,1) - r.congruency_effect_pre_alpha(:,1)); % cC
CSE{2}(:,1,2) = (r.congruency_effect_post_alpha(:,2) - r.congruency_effect_pre_alpha(:,2)); % iC
CSE{2}(:,2,1) = (r.congruency_effect_post_alpha(:,3) - r.congruency_effect_pre_alpha(:,3)); % cI
CSE{2}(:,2,2) = (r.congruency_effect_post_alpha(:,4) - r.congruency_effect_pre_alpha(:,4)); % iI

%%
subplot(235)
errorbar([1 2],squeeze(mean(CSE{1}(:,1,:))),squeeze(std(CSE{1}(:,1,:)))./sqrt(nsubjects),'-sr','markerfacecolor','r'); hold on
errorbar([1 2],squeeze(mean(CSE{1}(:,2,:))),squeeze(std(CSE{1}(:,2,:)))./sqrt(nsubjects),':or','markerfacecolor','r');
errorbar([3 4],squeeze(mean(CSE{2}(:,1,:))),squeeze(std(CSE{2}(:,1,:)))./sqrt(nsubjects),'-sb','markerfacecolor','b'); hold on
errorbar([3 4],squeeze(mean(CSE{2}(:,2,:))),squeeze(std(CSE{2}(:,2,:)))./sqrt(nsubjects),':ob','markerfacecolor','b');
set(gca,'xtick',[1 2 3 4],'xticklabel',{'c','i','c','i'},'xlim',[0.5 4.5],'ylim',[-10 20],'tickdir','out')
box off
xlabel('prev congruency')
title('[post-pre]')


%% CORRELATIONS

% The ANCOVA suggested that alpha peak frecuencies covaried with the CSE;
% to explore the direction, we first computed the 
% CSE = cI-cC - iI-iC, for the stimulation specific effect
% ([stim-pre]-[post-pre]), reflecting the interaction between previous,
% current congruency and pre/stim/post block
% This was done for alpha stimulatoin, and correlated with alpha peak
% frequency

CSE = zeros(nsubjects,2,2);

CSE(:,1,1) = (r.congruency_effect_stim_alpha(:,1) - r.congruency_effect_pre_alpha(:,1)) - (r.congruency_effect_post_alpha(:,1) - r.congruency_effect_pre_alpha(:,1)); % cC
CSE(:,1,2) = (r.congruency_effect_stim_alpha(:,2) - r.congruency_effect_pre_alpha(:,2)) - (r.congruency_effect_post_alpha(:,2) - r.congruency_effect_pre_alpha(:,2)); % iC
CSE(:,2,1) = (r.congruency_effect_stim_alpha(:,3) - r.congruency_effect_pre_alpha(:,3)) - (r.congruency_effect_post_alpha(:,3) - r.congruency_effect_pre_alpha(:,3)); % cI
CSE(:,2,2) = (r.congruency_effect_stim_alpha(:,4) - r.congruency_effect_pre_alpha(:,4)) - (r.congruency_effect_post_alpha(:,4) - r.congruency_effect_pre_alpha(:,4)); % iI

alpha_tACS_CSE = ((CSE(:,2,1)-CSE(:,1,1)) - (CSE(:,2,2)-CSE(:,1,2)));

subplot(236)
scatter(alphapeaks,alpha_tACS_CSE);
set(gca,'xlim',[5 15],'ylim',[-150 50])
lsline

[rho, pval] = corr(alphapeaks',alpha_tACS_CSE,'type','spearman','tail','right');
text(7,-75,['r = ' num2str(rho)]);
text(7,-100,['p = ' num2str(pval)]);

