* This SPSS syntax performs all analyses reported in the paper "Frequency band-specific electrical brain stimulation modulates cognitive control processes",
* authors: J. van Driel, I.G. Sligte, J. Linders, D. Elport and M. X Cohen.
* This file is part of Supporting Information file S2_File.zip
* SPSS data to perform the analyses are also provided
* In addition, these SPSS files can be produced with Matlab code that imports and preprocesses the raw data of the actual experiment log files.
* Below analyses focus on RT and residual RT after removing linear trend of practice over blocks (see main text and Matlab code).
* All analyses can also be done on accuracy (file: accuracy_dat.sav)
* Correspondence: joramvandriel@gmail.com


* first start with main RTs (dataset filename: RT_dat.sav).
DATASET ACTIVATE DataSet1.
OUTPUT NEW .


* ----------------------------------------------------------------
* main ANOVAS.
* full factorial design with frequency (theta/alpha), block (pre/stim/post), and previous (c/i) and current (C/I) congruency of Simon task stimuli.

GLM theta_pre_cC theta_pre_iC theta_pre_cI theta_pre_iI theta_stim_cC theta_stim_iC theta_stim_cI theta_stim_iI theta_post_cC theta_post_iC theta_post_cI theta_post_iI alpha_pre_cC alpha_pre_iC alpha_pre_cI alpha_pre_iI alpha_stim_cC alpha_stim_iC 
alpha_stim_cI alpha_stim_iI alpha_post_cC alpha_post_iC alpha_post_cI alpha_post_iI 
  /WSFACTOR=freq 2 Polynomial session 3 Polynomial curr 2 Polynomial prev 2 Polynomial 
  /METHOD=SSTYPE(3) 
  /PRINT=ETASQ 
  /CRITERIA=ALPHA(.05) 
  /WSDESIGN=freq session curr prev freq*session freq*curr session*curr freq*session*curr freq*prev session*prev freq*session*prev curr*prev freq*curr*prev session*curr*prev freq*session*curr*prev.

* now separately for theta and alpha stimulation.

GLM theta_pre_cC theta_pre_iC theta_pre_cI theta_pre_iI theta_stim_cC theta_stim_iC theta_stim_cI 
    theta_stim_iI theta_post_cC theta_post_iC theta_post_cI theta_post_iI
  /WSFACTOR=session 3 Polynomial curr 2 Polynomial prev 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=session curr prev session*curr session*prev curr*prev session*curr*prev.

GLM alpha_pre_cC alpha_pre_iC alpha_pre_cI alpha_pre_iI alpha_stim_cC alpha_stim_iC alpha_stim_cI 
    alpha_stim_iI alpha_post_cC alpha_post_iC alpha_post_cI alpha_post_iI
  /WSFACTOR=session 3 Polynomial curr 2 Polynomial prev 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=session curr prev session*curr session*prev curr*prev session*curr*prev.


* ----------------------------------------------------------------
* Compute difference scores.

* general CSE.
COMPUTE cCcI_all = mean(theta_pre_cC,theta_stim_cC,theta_post_cC,alpha_pre_cC,alpha_stim_cC,alpha_post_cC) - mean(theta_pre_cI,theta_stim_cI,theta_post_cI,alpha_pre_cI,alpha_stim_cI,alpha_post_cI).
COMPUTE iCiI_all=mean(theta_pre_iC,theta_stim_iC,theta_post_iC,alpha_pre_iC,alpha_stim_iC,alpha_post_iC)-mean(theta_pre_iI,theta_stim_iI,theta_post_iI,alpha_pre_iI,alpha_stim_iI,alpha_post_iI).

* freq-average CSE per block.
COMPUTE pre_CSE=mean(theta_pre_CSE,alpha_pre_CSE). 
COMPUTE stim_CSE=mean(theta_stim_CSE,alpha_stim_CSE). 
COMPUTE post_CSE=mean(theta_post_CSE,alpha_post_CSE). 

EXECUTE .


* ----------------------------------------------------------------
* t-tests for directionality.

* conflict-effect after non-conflict trial versus conflict-effect after conflict trial.
T-TEST PAIRS=cCcI_all WITH iCiI_all (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

* test either against zero.
T-TEST
  /TESTVAL=0
  /MISSING=ANALYSIS
  /VARIABLES=iCiI_all cCcI_all
  /CRITERIA=CI(.95).

* compare the CSE (cI-cC - iI-iC) between pre/stim/post blocks.
T-TEST PAIRS=pre_CSE pre_CSE stim_CSE WITH stim_CSE post_CSE post_CSE (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


* ----------------------------------------------------------------
* switch to dataset with RT residuals (removing linear effect of block on main RT), named RT_residuals_dat.sav .
DATASET ACTIVATE DataSet2.
OUTPUT NEW .


* ----------------------------------------------------------------
* Compute difference scores

* freq-specific tACS effect: (stim-pre)-(post-pre).
COMPUTE tACS_theta_cC=(theta_stim_cC - theta_pre_cC) - (theta_post_cC - theta_pre_cC).
COMPUTE tACS_theta_cI=(theta_stim_cI - theta_pre_cI) - (theta_post_cI - theta_pre_cI).
COMPUTE tACS_theta_iC=(theta_stim_iC - theta_pre_iC) - (theta_post_iC - theta_pre_iC).
COMPUTE tACS_theta_iI=(theta_stim_iI - theta_pre_iI) - (theta_post_iI - theta_pre_iI).
COMPUTE tACS_alpha_cC=(alpha_stim_cC - alpha_pre_cC) - (alpha_post_cC - alpha_pre_cC).
COMPUTE tACS_alpha_cI=(alpha_stim_cI - alpha_pre_cI) - (alpha_post_cI - alpha_pre_cI).
COMPUTE tACS_alpha_iC=(alpha_stim_iC - alpha_pre_iC) - (alpha_post_iC - alpha_pre_iC).
COMPUTE tACS_alpha_iI=(alpha_stim_iI - alpha_pre_iI) - (alpha_post_iI - alpha_pre_iI).

* freq-specific cI-cC versus iI-iC per block.
COMPUTE theta_pre_cIcC = theta_pre_cI- theta_pre_cC.
COMPUTE theta_stim_cIcC = theta_stim_cI - theta_stim_cC.
COMPUTE theta_post_cIcC = theta_post_cI - theta_post_cC.
COMPUTE theta_pre_iIiC = theta_pre_iI- theta_pre_iC.
COMPUTE theta_stim_iIiC = theta_stim_iI - theta_stim_iC.
COMPUTE theta_post_iIiC = theta_post_iI - theta_post_iC.
COMPUTE alpha_pre_cIcC = alpha_pre_cI- alpha_pre_cC.
COMPUTE alpha_stim_cIcC = alpha_stim_cI - alpha_stim_cC.
COMPUTE alpha_post_cIcC = alpha_post_cI - alpha_post_cC.
COMPUTE alpha_pre_iIiC = alpha_pre_iI- alpha_pre_iC.
COMPUTE alpha_stim_iIiC = alpha_stim_iI - alpha_stim_iC.
COMPUTE alpha_post_iIiC = alpha_post_iI - alpha_post_iC.

* freq-specific stimulation-after-effect of conflict adaptation.
COMPUTE prepost_theta_iC=(theta_post_iC - theta_pre_iC).
COMPUTE prepost_theta_iI=(theta_post_iI - theta_pre_iI).
COMPUTE prepost_alpha_iC=(alpha_post_iC - alpha_pre_iC).
COMPUTE prepost_alpha_iI=(alpha_post_iI - alpha_pre_iI).

EXECUTE.


* ----------------------------------------------------------------
* t-tests for directionality.

* compare the theta tACS effect (stim-pre - post-pre) for low (cC) versus high (cI) conflict trials.
T-TEST PAIRS=tACS_theta_cC  WITH tACS_theta_cI (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

* test either against zero.
T-TEST
  /TESTVAL=0
  /MISSING=ANALYSIS
  /VARIABLES=tACS_theta_cC tACS_theta_cI
  /CRITERIA=CI(.95).

* same for conflict adaptation: iC versus iI.
T-TEST PAIRS=tACS_theta_iC  WITH tACS_theta_iI (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

* and same for alpha.
T-TEST PAIRS=tACS_alpha_cC  WITH tACS_alpha_cI (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

T-TEST PAIRS=tACS_alpha_iC  WITH tACS_alpha_iI (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


* ----------------------------------------------------------------
* ANOVAs separately for conflict detection (cI-cC) and adaptation (iI-iC), for theta and alpha separately.

GLM theta_pre_cIcC theta_stim_cIcC theta_post_cIcC
  /WSFACTOR=block 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=block.

GLM theta_pre_iIiC theta_stim_iIiC theta_post_iIiC
  /WSFACTOR=block 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=block.

GLM alpha_pre_cIcC alpha_stim_cIcC alpha_post_cIcC
  /WSFACTOR=block 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=block.

GLM alpha_pre_iIiC alpha_stim_iIiC alpha_post_iIiC
  /WSFACTOR=block 3 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=block.


* ----------------------------------------------------------------
* t-test for directionality of conflict adaptation effect.

* compare pre/stim/post iC trials .
T-TEST PAIRS=theta_pre_iC theta_stim_iC theta_post_iC WITH theta_stim_iC theta_post_iC theta_pre_iC (PAIRED)
   /CRITERIA=CI(.9500)
   /MISSING=ANALYSIS.

* same for iI trials .
T-TEST PAIRS=theta_pre_iI theta_stim_iI theta_post_iI WITH theta_stim_iI theta_post_iI theta_pre_iI (PAIRED)
   /CRITERIA=CI(.9500)
   /MISSING=ANALYSIS.

* test linear effect over blocks (post versus pre) .
T-TEST PAIRS=prepost_theta_iC  WITH prepost_theta_iI (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

T-TEST PAIRS=prepost_alpha_iC  WITH prepost_alpha_iI (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.


* ----------------------------------------------------------------
* ANCOVA with peak frequency as covariate .

GLM theta_pre_cC theta_pre_iC theta_pre_cI theta_pre_iI theta_stim_cC theta_stim_iC theta_stim_cI 
    theta_stim_iI theta_post_cC theta_post_iC theta_post_cI theta_post_iI WITH peakfreqtheta 
  /WSFACTOR=session 3 Polynomial curr 2 Polynomial prev 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=session curr prev session*curr session*prev curr*prev session*curr*prev
  /DESIGN=peakfreqtheta.

GLM alpha_pre_cC alpha_pre_iC alpha_pre_cI alpha_pre_iI alpha_stim_cC alpha_stim_iC alpha_stim_cI 
    alpha_stim_iI alpha_post_cC alpha_post_iC alpha_post_cI alpha_post_iI WITH peakfreqalpha
  /WSFACTOR=session 3 Polynomial curr 2 Polynomial prev 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=session curr prev session*curr session*prev curr*prev session*curr*prev
  /DESIGN=peakfreqalpha. 


* ----------------------------------------------
* Post-error slowing.

* activate dataset named 'PES_residuals_dat.sav'.
DATASET ACTIVATE DataSet3.
OUTPUT NEW .

GLM theta_pre_cCc theta_pre_eC theta_stim_cCc theta_stim_eC theta_post_cCc theta_post_eC 
    alpha_pre_cCc alpha_pre_eC alpha_stim_cCc alpha_stim_eC alpha_post_cCc alpha_post_eC
  /WSFACTOR=freq 2 Polynomial block 3 Polynomial acc 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=freq block acc freq*block freq*acc block*acc freq*block*acc.

T-TEST PAIRS=theta_pre_cCc theta_pre_eC alpha_pre_cCc alpha_pre_eC WITH theta_post_cCc 
    theta_post_eC alpha_post_cCc alpha_post_eC (PAIRED)
  /CRITERIA=CI(.9500)
  /MISSING=ANALYSIS.

* Error speeding .

GLM theta_pre_cCc theta_pre_cE theta_stim_cCc theta_stim_cE theta_post_cCc theta_post_cE 
    alpha_pre_cCc alpha_pre_cE alpha_stim_cCc alpha_stim_cE alpha_post_cCc alpha_post_cE
  /WSFACTOR=freq 2 Polynomial block 3 Polynomial acc 2 Polynomial 
  /METHOD=SSTYPE(3)
  /PRINT=ETASQ 
  /CRITERIA=ALPHA(.05)
  /WSDESIGN=freq block acc freq*block freq*acc block*acc freq*block*acc.

T-TEST PAIRS=theta_stim_cE WITH alpha_stim_cE (PAIRED) 
  /CRITERIA=CI(.9500) 
  /MISSING=ANALYSIS.


